@@ -45,7 +45,6 @@ import json
 import os
 
 from ..settings_dispatcher import SettingsDispatcher
-from ...utils import path
 
 
 class SettingsError(Exception):
@@ -60,19 +59,11 @@ class DuplicatedNamespace(SettingsError):
     """
 
 
-class ConfigFileNotFound(SettingsError):
+class NamespaceNotRegistered(SettingsError):
     """
-    Error thrown when the main settings file could not be found.
+    Raised when a namespace is not registered.
     """
 
-    def __init__(self, path_list):
-        super(ConfigFileNotFound, self).__init__()
-        self.path_list = path_list
-
-    def __str__(self):
-        return ("Could not find the avocado config file after looking in: %s" %
-                self.path_list)
-
 
 class ConfigOption:
     def __init__(self, namespace, help_msg, key_type=str, default=None,
@@ -94,6 +85,8 @@ class ConfigOption:
         self._action = action
         self._value = None
 
+        self._update_argparser()
+
     @property
     def action(self):
         if self.key_type is bool:
@@ -182,6 +175,32 @@ class ConfigOption:
 
         raise ValueError("{} could not be converted into a list".format(value))
 
+    def _update_argparser(self):
+        if not self.parser:
+            return
+
+        if self.positional_arg:
+            self.parser.add_argument(self.namespace, **self.arg_parse_args)
+        else:
+            self.parser.add_argument(*self.name_or_tags, **self.arg_parse_args)
+
+    def add_argparser(self, parser, long_arg, short_arg=None,
+                      positional_arg=False, choices=None, nargs=None,
+                      metavar=None, required=None, action=None):
+        """Add an command-line argparser to this option."""
+
+        self.parser = parser
+        self.short_arg = short_arg
+        self.long_arg = long_arg
+        self.positional_arg = positional_arg
+        self.choices = choices
+        self.nargs = nargs
+        self._metavar = metavar
+        self.required = required
+        self._action = action
+
+        self._update_argparser()
+
     def set_value(self, value, convert=False):
         dst_type = self.key_type
 
@@ -246,9 +265,6 @@ class Settings:
         # 2. Parse/read all config paths
         self._config_paths = self._config.read(self._all_config_paths)
 
-        if not self._config_paths:
-            raise ConfigFileNotFound(self._all_config_paths)
-
     def _append_config_paths(self):
         # Override with system config
         self._append_system_config()
@@ -270,21 +286,8 @@ class Settings:
             self._all_config_paths.append(extra_file)
 
     def _append_user_config(self):
-        if not os.path.exists(self._config_path_local):
-            self._create_empty_config()
-        self._all_config_paths.append(self._config_path_local)
-
-    def _create_empty_config(self):
-        try:
-            path.init_dir(self._config_dir_local)
-            with open(self._config_path_local, 'w') as config_local_fileobj:
-                content = ("# You can use this file to override "
-                           "configuration values from '%s and %s\n"
-                           % (self._config_path_system,
-                              self._config_dir_system_extra))
-                config_local_fileobj.write(content)
-        except IOError:     # Some users can't write it (docker)
-            pass
+        if os.path.exists(self._config_path_local):
+            self._all_config_paths.append(self._config_path_local)
 
     def _prepare_base_dirs(self):
         cfg_dir = '/etc'
@@ -304,6 +307,79 @@ class Settings:
         self._config_path_local = os.path.join(self._config_dir_local,
                                                'avocado.conf')
 
+    def add_argparser_to_option(self, namespace, parser, long_arg,
+                                short_arg=None, positional_arg=False,
+                                choices=None, nargs=None, metavar=None,
+                                required=None, action=None,
+                                allow_multiple=False):
+        """Add a command-line argument parser to an existing option.
+
+        This method is useful to add a parser when the option is registered
+        without any command-line argument options. You should call the
+        "register_option()" method for the namespace before calling this
+        method.
+
+        Arguments
+
+        namespace : str
+            What is the namespace of the option (section.key)
+
+        parser : argparser parser
+            Since that you would like to have a command-line option, you should
+            specify what is the parser or parser group that we should add this
+            option.
+
+        long_arg: : str
+            A long option for the command-line. i.e: `--debug` for debug.
+
+        short_arg : str
+            A short option for the command-line. i.e: `-d` for debug.
+
+        positional_arg : bool
+            If this option is an positional argument or not. Default is
+            `False`.
+
+        choices : tuple
+            If you would like to limit the option to a few choices. i.e:
+            ('foo', 'bar')
+
+        nargs : int or str
+            The number of command-line arguments that should be consumed. Could
+            be a int, '?', '*' or '+'. For more information visit the argparser
+            documentation.
+
+        metavar : str
+            String presenting available sub-commands in help, if None we will
+            use the section+key as metavar.
+
+        required : bool
+            If this is a required option or not when on command-line. Default
+            is False.
+
+        action :
+            The basic type of action to be taken when this argument is
+            encountered at the command line. For more information visit the
+            argparser documentation.
+
+        allow_multiple :
+            Whether the same option may be available on different parsers.
+            This is useful when the same option is available on different
+            commands, such as "avocado run" or "avocado list".
+        """
+        option = None
+        try:
+            option = self._namespaces[namespace]
+        except KeyError:
+            msg = "Namespace not found: {}".format(namespace)
+            raise NamespaceNotRegistered(msg)
+
+        if option and option.parser and not allow_multiple:
+            msg = "Parser already registered for this namespace"
+            raise SettingsError(msg)
+
+        option.add_argparser(parser, short_arg, long_arg, positional_arg,
+                             choices, nargs, metavar, required, action)
+
     def as_dict(self):
         """Return an dictionary with the current active settings.
 
@@ -360,7 +436,7 @@ class Settings:
     def register_option(self, section, key, default, help_msg, key_type=str,
                         parser=None, positional_arg=False, short_arg=None,
                         long_arg=None, choices=None, nargs=None, metavar=None,
-                        required=False, action=None):
+                        required=False, action=None, allow_multiple=False):
         """Method used to register a configuration option inside Avocado.
 
         This should be used to register a settings option (either config file
@@ -449,6 +525,11 @@ class Settings:
             encountered at the command line. For more information visit the
             argparser documentation.
 
+        allow_multiple :
+            Whether the same option may be available on different parsers.
+            This is useful when the same option is available on different
+            commands, such as "avocado run" or "avocado list".
+
         .. note:: Most of the arguments here (like parser, positional_arg,
                   short_arg, long_arg, choices, nargs, metavar, required and
                   action) are only necessary if you would like to add a
@@ -457,24 +538,23 @@ class Settings:
         namespace = "{}.{}".format(section, key)
         # Check if namespace is already registered
         if namespace in self._namespaces:
-            msg = "Key {} already registered in section {}".format(key,
-                                                                   section)
-            raise DuplicatedNamespace(msg)
-
-        option = ConfigOption(namespace, help_msg, key_type, default,
-                              parser, short_arg, long_arg, positional_arg,
-                              choices, nargs, metavar, required, action)
-
-        # Register the option to a dynamic in-memory namespaces
-        self._namespaces[namespace] = option
-
-        if not parser:
-            return  # Nothing else to do here
-
-        if positional_arg:
-            parser.add_argument(namespace, **option.arg_parse_args)
+            if not allow_multiple:
+                msg = 'Key "{}" already registered under section "{}"'.format(key,
+                                                                              section)
+                raise DuplicatedNamespace(msg)
+            else:
+                self.add_argparser_to_option(namespace, parser, long_arg,
+                                             short_arg, positional_arg,
+                                             choices, nargs, metavar,
+                                             required, action,
+                                             allow_multiple)
         else:
-            parser.add_argument(*option.name_or_tags, **option.arg_parse_args)
+            option = ConfigOption(namespace, help_msg, key_type, default,
+                                  parser, short_arg, long_arg, positional_arg,
+                                  choices, nargs, metavar, required, action)
+
+            # Register the option to a dynamic in-memory namespaces
+            self._namespaces[namespace] = option
 
     def update_option(self, namespace, value, convert=False):
         """Convenient method to change the option's value.
