@@ -20,12 +20,15 @@ Job module - describes a sequence of automated test operations.
 import argparse
 import logging
 import os
+import pprint
 import re
 import shutil
 import sys
 import tempfile
 import time
 import traceback
+import uuid
+import warnings
 
 from . import data_dir
 from . import dispatcher
@@ -39,7 +42,6 @@ from . import output
 from . import resolver
 from . import result
 from . import tags
-from . import test
 from . import varianter
 from . import version
 from ..utils import astring
@@ -50,8 +52,9 @@ from ..utils import stacktrace
 from .output import LOG_JOB
 from .output import LOG_UI
 from .output import STD_OUTPUT
-from .settings import settings
+from .future.settings import settings
 from .tags import filter_test_tags_runnable
+from .test import DryRunTest
 
 
 _NEW_ISSUE_LINK = 'https://github.com/avocado-framework/avocado/issues/new'
@@ -69,10 +72,9 @@ def resolutions_to_tasks(resolutions, config):
     :class:`avocado.core.nrunner.Runnable`.
 
     This method transforms those runnables into Tasks
-    (:class:`avocado.core.nrunner.Task`), which will include an
-    unique sequential identification and a status reporting URI.
-    It also performs tag based filtering on the runnables for
-    possibly excluding some of the Runnables.
+    (:class:`avocado.core.nrunner.Task`), which will include a status
+    reporting URI.  It also performs tag based filtering on the
+    runnables for possibly excluding some of the Runnables.
 
     :param resolutions: possible multiple resolutions for multiple
                         references
@@ -84,31 +86,42 @@ def resolutions_to_tasks(resolutions, config):
     """
 
     tasks = []
-    index = 0
     resolutions = [res for res in resolutions if
                    res.result == resolver.ReferenceResolutionResult.SUCCESS]
-    no_digits = len(str(len(resolutions)))
+    filter_by_tags = config.get("filter.by_tags.tags")
     for resolution in resolutions:
-        name = resolution.reference
         for runnable in resolution.resolutions:
-            filter_by_tags = config.get('filter_by_tags')
             if filter_by_tags:
                 if not filter_test_tags_runnable(
                         runnable,
                         filter_by_tags,
-                        config.get('filter_by_tags_include_empty'),
-                        config.get('filter_by_tags_include_empty_key')):
+                        config.get("filter.by_tags.include_empty"),
+                        config.get('filter.by_tags.include_empty_key')):
                     continue
-            if runnable.uri:
-                name = runnable.uri
-            identifier = str(test.TestID(index + 1, name, None, no_digits))
             status_server = config.get('nrun.status_server.listen')
-            tasks.append(nrunner.Task(identifier, runnable,
+            tasks.append(nrunner.Task(str(uuid.uuid1()), runnable,
                                       [status_server]))
-            index += 1
     return tasks
 
 
+def register_job_options():
+    """Register the few core options that the support the job operation."""
+    msg = (
+        "Sets the base log level of the output generated by the job, which "
+        "is also the base loging level for the --show command line option. "
+        "Any of the Python logging levels names are allowed here. Examples:"
+        " DEBUG, INFO, WARNING, ERROR, CRITICAL. For more information refer"
+        " to: https://docs.python.org/3/library/logging.html#levels"
+        )
+    settings.register_option(section='job.output',
+                             key='loglevel',
+                             default='DEBUG',
+                             help_msg=msg)
+
+
+register_job_options()
+
+
 class Job:
 
     """
@@ -118,12 +131,6 @@ class Job:
     along with setup operations and event recording.
     """
 
-    LOG_MAP = {'info': logging.INFO,
-               'debug': logging.DEBUG,
-               'warning': logging.WARNING,
-               'error': logging.ERROR,
-               'critical': logging.CRITICAL}
-
     def __init__(self, config=None):
         """
         Creates an instance of Job class.
@@ -132,13 +139,14 @@ class Job:
                        line options and argument parsing
         :type config: dict
         """
-        self.config = config or {}
+        self.config = settings.as_dict()
+        if config:
+            self.config.update(config)
         self.log = LOG_UI
-        self.loglevel = self.LOG_MAP.get(settings.get_value('job.output',
-                                                            'loglevel',
-                                                            default='debug'),
-                                         logging.DEBUG)
+        self.loglevel = self.config.get('job.output.loglevel')
         self.__logging_handlers = {}
+        # TODO: Fix this, this is one of the few cases where using the config
+        # generated from the new settings with a hardcoded 'default' value
         self.standalone = self.config.get('standalone', False)
         if self.config.get('run.dry_run.enabled'):  # Modify args for dry-run
             unique_id = self.config.get('run.unique_job_id')
@@ -160,7 +168,6 @@ class Job:
         self.status = "RUNNING"
         self.result = None
         self.interrupted_reason = None
-        self.sysinfo = None
         timeout = self.config.get('run.job_timeout')
         try:
             self.timeout = data_structures.time_to_seconds(timeout)
@@ -181,13 +188,19 @@ class Job:
                                                            % self.unique_id,
                                                            LOG_JOB)
         self._stdout_stderr = None
-        self.replay_sourcejob = self.config.get('replay_sourcejob', None)
+        self.replay_sourcejob = self.config.get('replay_sourcejob')
         self.exitcode = exit_codes.AVOCADO_ALL_OK
         #: The list of discovered/resolved tests that will be attempted to
         #: be run by this job.  If set to None, it means that test resolution
         #: has not been attempted.  If set to an empty list, it means that no
         #: test was found during resolution.
         self.test_suite = None
+        # To avoid requiring an explicit runner from Job API users, this sets
+        # a job built-in default for the runner
+        self._test_runner_name = self.config.get('run.test_runner') or 'runner'
+        #: An instance of the :class:`avocado.core.plugin_interfaces.Runner`
+        #: that will be used to effectively run the tests in the this job's
+        #: :attr:`test_suite`
         self.test_runner = None
 
         #: Placeholder for test parameters (related to --test-parameters command
@@ -325,8 +338,8 @@ class Job:
         fmt = '%(asctime)s %(levelname)-5.5s| %(message)s'
         formatter = logging.Formatter(fmt=fmt, datefmt='%H:%M:%S')
 
-        # TODO: Fix this, this is the only case using the new settings where
-        # get has a 'default' value
+        # TODO: Fix this, this is one of the few cases where using the config
+        # generated from the new settings with a hardcoded 'default' value
         try:
             store_logging_stream = self.config.get('run.store_logging_stream', [])
         except AttributeError:
@@ -354,7 +367,7 @@ class Job:
                 self.__logging_handlers[handler] = [name]
 
         # Enable console loggers
-        enabled_logs = self.config.get("show", [])
+        enabled_logs = self.config.get("core.show")
         if ('test' in enabled_logs and
                 'early' not in enabled_logs):
             self._stdout_stderr = sys.stdout, sys.stderr
@@ -421,12 +434,13 @@ class Job:
         try:
             force = self.config.get('run.ignore_missing_references')
             suite = loader.loader.discover(references, force=force)
-            if self.config.get('filter_by_tags', False):
+            filter_tags = self.config.get("filter.by_tags.tags")
+            if filter_tags:
                 suite = tags.filter_test_tags(
                     suite,
-                    self.config.get('filter_by_tags'),
-                    self.config.get('filter_by_tags_include_empty'),
-                    self.config.get('filter_by_tags_include_empty_key'))
+                    filter_tags,
+                    self.config.get("filter.by_tags.include_empty"),
+                    self.config.get('filter.by_tags.include_empty_key'))
         except loader.LoaderUnhandledReferenceError as details:
             raise exceptions.OptionValidationError(details)
         except KeyboardInterrupt:
@@ -435,7 +449,7 @@ class Job:
         if not self.config.get('run.dry_run.enabled'):
             return suite
         for i in range(len(suite)):
-            suite[i] = [test.DryRunTest, suite[i][1]]
+            suite[i] = [DryRunTest, suite[i][1]]
         return suite
 
     def _make_test_suite_resolver(self, references):
@@ -489,22 +503,10 @@ class Job:
         LOG_JOB.info('Avocado version: %s', version_log)
         LOG_JOB.info('')
 
-    @staticmethod
-    def _log_avocado_config():
-        LOG_JOB.info('Config files read (in order):')
-        for cfg_path in settings.config_paths:
-            LOG_JOB.info(cfg_path)
-        LOG_JOB.info('')
-
+    def _log_avocado_config(self):
         LOG_JOB.info('Avocado config:')
-        header = ('Section.Key', 'Value')
-        config_matrix = []
-        for section in settings.config.sections():
-            for value in settings.config.items(section):
-                config_key = ".".join((section, value[0]))
-                config_matrix.append([config_key, value[1]])
-
-        for line in astring.iter_tabular_output(config_matrix, header):
+        LOG_JOB.info('')
+        for line in pprint.pformat(self.config).splitlines():
             LOG_JOB.info(line)
         LOG_JOB.info('')
 
@@ -546,15 +548,11 @@ class Job:
         This is a public Job API as part of the documented Job phases
         """
         refs = self.config.get('run.references')
-        if not refs:
-            refs = self.config.get('nrun.references')
-        runner_name = self.config.get('test_runner', 'runner')
         try:
-            if runner_name == 'nrunner':
+            if self._test_runner_name == 'nrunner':
                 self.test_suite = self._make_test_suite_resolver(refs)
             else:
                 self.test_suite = self._make_test_suite_loader(refs)
-            self.result.tests_total = len(self.test_suite)
         except loader.LoaderError as details:
             stacktrace.log_exc_info(sys.exc_info(), LOG_UI.getChild("debug"))
             raise exceptions.OptionValidationError(details)
@@ -569,6 +567,8 @@ class Job:
                          "executed command.")
             raise exceptions.OptionValidationError(e_msg)
 
+        self.result.tests_total = len(self.test_suite)
+
     def pre_tests(self):
         """
         Run the pre tests execution hooks
@@ -582,10 +582,8 @@ class Job:
         """
         The actual test execution phase
         """
-        variant = self.config.get("avocado_variants", None)
+        variant = self.config.get("avocado_variants")
         refs = self.config.get('run.references')
-        if not refs:
-            refs = self.config.get('nrun.references')
         if variant is None:
             variant = varianter.Varianter()
         if not variant.is_parsed():   # Varianter not yet parsed, apply args
@@ -595,9 +593,8 @@ class Job:
                 raise exceptions.OptionValidationError("Unable to parse "
                                                        "variant: %s" % details)
 
-        runner_name = self.config.get('test_runner', 'runner')
         try:
-            runner_extension = dispatcher.RunnerDispatcher()[runner_name]
+            runner_extension = dispatcher.RunnerDispatcher()[self._test_runner_name]
         except KeyError:
             return
         self.test_runner = runner_extension.obj
@@ -605,7 +602,7 @@ class Job:
         self._log_job_debug_info(variant)
         jobdata.record(self.config, self.logdir, variant,
                        refs, sys.argv)
-        replay_map = self.config.get('replay_map', None)
+        replay_map = self.config.get('replay_map')
         execution_order = self.config.get('run.execution_order')
         summary = self.test_runner.run_suite(self,
                                              self.result,
@@ -639,6 +636,16 @@ class Job:
         """
         self.result_events_dispatcher.map_method('post_tests', self)
 
+    def render_results(self):
+        """Render test results that depend on all tests having finished.
+
+        By default this runs the plugins that implement the
+        :class:`avocado.core.plugin_interfaces.Result` interface.
+        """
+        result_dispatcher = dispatcher.ResultDispatcher()
+        if result_dispatcher.extensions:
+            result_dispatcher.map_method('render', self.result, self)
+
     def run(self):
         """
         Runs all job phases, returning the test execution results.
@@ -686,6 +693,7 @@ class Job:
             if self.time_end == -1:
                 self.time_end = time.time()
                 self.time_elapsed = self.time_end - self.time_start
+            self.render_results()
 
     def cleanup(self):
         """
@@ -729,6 +737,10 @@ class TestProgram:
             sys.exit(exit_codes.AVOCADO_FAIL)
         os.environ['AVOCADO_STANDALONE_IN_MAIN'] = 'True'
 
+        warnings.warn("The standalone job feature will be removed soon. "
+                      "It can be replaced in the future by using the Job API "
+                      "and use __file__ as a reference.", FutureWarning)
+
         self.prog_name = os.path.basename(sys.argv[0])
         output.add_log_handler("", output.ProgressStreamHandler,
                                fmt="%(message)s")
@@ -750,7 +762,7 @@ class TestProgram:
 
     def run_tests(self):
         self.config['standalone'] = True
-        self.config['show'] = ["test"]
+        self.config['core.show'] = ["test"]
         output.reconfigure(self.config)
         with Job(self.config) as self.job:
             exit_status = self.job.run()
