@@ -599,7 +599,7 @@ class Task:
             known_runners = {}
         self.known_runners = known_runners
         self.spawn_handle = None
-        self._output_dir = None
+        self.output_dir = None
 
     def __repr__(self):
         fmt = '<Task identifier="{}" runnable="{}" status_services="{}"'
@@ -617,8 +617,8 @@ class Task:
         return self.runnable.pick_runner_command(runners_registry)
 
     def setup_output_dir(self):
-        self._output_dir = tempfile.mkdtemp(prefix='.avocado-task-')
-        env_var = {'AVOCADO_TEST_OUTPUT_DIR': self._output_dir}
+        self.output_dir = tempfile.mkdtemp(prefix='.avocado-task-')
+        env_var = {'AVOCADO_TEST_OUTPUT_DIR': self.output_dir}
         self.runnable.kwargs.update(env_var)
 
     @classmethod
@@ -667,7 +667,7 @@ class Task:
         runner = runner_klass(self.runnable)
         for status in runner.run():
             if status['status'] == 'started':
-                status.update({'output_dir': self._output_dir})
+                status.update({'output_dir': self.output_dir})
             status.update({"id": self.identifier})
             for status_service in self.status_services:
                 status_service.post(status)
@@ -696,7 +696,8 @@ class StatusServer:
                     return True
 
             message = await reader.readline()
-            if message == b'bye\n':
+            message = message.strip()
+            if message == b'bye':
                 print('Status server: exiting due to user request')
                 self.server_task.cancel()
                 await self.server_task
@@ -705,7 +706,10 @@ class StatusServer:
             if not message:
                 return False
 
-            data = json_loads(message.strip())
+            try:
+                data = json_loads(message)
+            except json.decoder.JSONDecodeError:
+                return False
 
             if data.get('status') in ['started']:
                 self.handle_task_started(data)
@@ -716,7 +720,7 @@ class StatusServer:
         host, port = self.uri.split(':')
         port = int(port)
         server = await asyncio.start_server(self.cb, host=host, port=port)
-        print("Results server started at:", self.uri)
+        print("Status server started at:", self.uri)
         await server.wait_closed()
 
     def handle_task_started(self, data):
@@ -731,23 +735,25 @@ class StatusServer:
         result = data['result']
         task_id = data['id']
 
-        self.tasks_pending.remove(task_id)
-        print('Task complete (%s): %s' % (result, task_id))
+        if self.wait_on_tasks_pending:
+            self.tasks_pending.remove(task_id)
 
         if result not in self.result:
             self.result[result] = []
         self.result[result].append(task_id)
 
-        if result not in ('pass', 'skip'):
-            stdout = data.get('stdout', b'')
-            if stdout:
-                print('Task %s stdout:\n%s\n' % (task_id, stdout))
-            stderr = data.get('stderr', b'')
-            if stderr:
-                print('Task %s stderr:\n%s\n' % (task_id, stderr))
-            output = data.get('output', b'')
-            if output:
-                print('Task %s output:\n%s\n' % (task_id, output))
+        if self.verbose:
+            print('Task complete (%s): %s' % (result, task_id))
+            if result not in ('pass', 'skip'):
+                stdout = data.get('stdout', b'')
+                if stdout:
+                    print('Task %s stdout:\n%s\n' % (task_id, stdout))
+                stderr = data.get('stderr', b'')
+                if stderr:
+                    print('Task %s stderr:\n%s\n' % (task_id, stderr))
+                output = data.get('output', b'')
+                if output:
+                    print('Task %s output:\n%s\n' % (task_id, output))
 
     def start(self):
         loop = asyncio.get_event_loop()
@@ -824,6 +830,7 @@ class BaseRunnerApp:
             prog = self.PROG_NAME
         if description is None:
             description = self.PROG_DESCRIPTION
+        self._class_commands_method = self._get_commands_method()
         self._setup_parser(prog, description)
 
     def _setup_parser(self, prog, description):
@@ -831,25 +838,24 @@ class BaseRunnerApp:
                                               description=description)
         subcommands = self.parser.add_subparsers(dest='subcommand')
         subcommands.required = True
-        for cmd_meth in self._get_commands_method_without_prefix():
-            attr = "CMD_%s_ARGS" % cmd_meth.upper()
-            cmd = cmd_meth.replace('_', '-')
-            cmd_parser = subcommands.add_parser(
-                cmd,
-                help=self._get_command_method_help_message(cmd_meth))
-            if hasattr(self, attr):
-                for arg in getattr(self, attr):
-                    cmd_parser.add_argument(*arg[0], **arg[1])
+        for command, method in self._class_commands_method.items():
+            command_args = "CMD_%s_ARGS" % command.upper().replace('-', '_')
+            command_parser = subcommands.add_parser(
+                command,
+                help=self._get_command_method_help_message(method))
+            if hasattr(self, command_args):
+                for arg in getattr(self, command_args):
+                    command_parser.add_argument(*arg[0], **arg[1])
 
-    def _get_commands_method_without_prefix(self):
+    def _get_commands_method(self):
         prefix = 'command_'
-        return [c[0][len(prefix):]
+        return {c[0][len(prefix):].replace('_', '-'): getattr(self, c[0])
                 for c in inspect.getmembers(self, inspect.ismethod)
-                if c[0].startswith(prefix)]
+                if c[0].startswith(prefix)}
 
     def _get_command_method_help_message(self, command_method):
         help_message = ''
-        docstring = getattr(self, 'command_%s' % command_method).__doc__
+        docstring = command_method.__doc__
         if docstring:
             docstring_lines = docstring.strip().splitlines()
             if docstring_lines:
@@ -862,11 +868,9 @@ class BaseRunnerApp:
         """
         args = vars(self.parser.parse_args())
         subcommand = args.get('subcommand')
-        if subcommand in self.get_commands():
-            meth_name = 'command_' + subcommand.replace('-', '_')
-            if hasattr(self, meth_name):
-                kallable = getattr(self, meth_name)
-                return kallable(args)
+        kallable = self._class_commands_method.get(subcommand, None)
+        if kallable is not None:
+            return kallable(args)
 
     def get_commands(self):
         """
@@ -879,8 +883,7 @@ class BaseRunnerApp:
 
         :rtype: list
         """
-        return [c.replace('_', '-') for c in
-                self._get_commands_method_without_prefix()]
+        return list(self._class_commands_method.keys())
 
     def get_capabilities(self):
         """
@@ -892,7 +895,7 @@ class BaseRunnerApp:
 
         :rtype: dict
         """
-        return {"runnables": [k for k in self.RUNNABLE_KINDS_CAPABLE.keys()],
+        return {"runnables": list(self.RUNNABLE_KINDS_CAPABLE.keys()),
                 "commands": self.get_commands()}
 
     def get_runner_from_runnable(self, runnable):
