@@ -25,7 +25,6 @@ from avocado.core import job
 from avocado.core import loader
 from avocado.core import output
 from avocado.core import parser_common_args
-from avocado.core.dispatcher import ResultDispatcher
 from avocado.core.dispatcher import JobPrePostDispatcher
 from avocado.core.future.settings import settings
 from avocado.core.output import LOG_UI
@@ -87,6 +86,19 @@ class Run(CLICmd):
                                  long_arg='--test-parameter',
                                  short_arg='-p')
 
+        help_msg = ('Selects the runner implementation from one of the '
+                    'installed and active implementations.  You can run '
+                    '"avocado plugins" and find the list of valid runners '
+                    'under the "Plugins that run test suites on a job '
+                    '(runners) section.  Defaults to "runner", which is '
+                    'the conventional and traditional runner.')
+        settings.register_option(section='run',
+                                 key='test_runner',
+                                 default='runner',
+                                 help_msg=help_msg,
+                                 parser=parser,
+                                 long_arg='--test-runner')
+
         help_msg = ('Instead of running the test only list them and log '
                     'their params.')
         settings.register_option(section='run.dry_run',
@@ -181,17 +193,11 @@ class Run(CLICmd):
                                  parser=parser,
                                  long_arg='--ignore-missing-references')
 
-        help_msg = ('Enable or disable sysinfo information. Like hardware '
-                    'details, profiles, etc.')
-        settings.register_option(section='sysinfo.collect',
-                                 key='enabled',
-                                 default='on',
-                                 key_type=str,
-                                 help_msg=help_msg,
-                                 choices=('on', 'off'),
-                                 parser=parser,
-                                 short_arg='-S',
-                                 long_arg='--sysinfo')
+        settings.add_argparser_to_option(namespace='sysinfo.collect.enabled',
+                                         parser=parser,
+                                         choices=('on', 'off'),
+                                         short_arg='-S',
+                                         long_arg='--sysinfo')
 
         help_msg = ('Defines the order of iterating through test suite '
                     'and test variants')
@@ -266,7 +272,7 @@ class Run(CLICmd):
                                  parser=out_check,
                                  long_arg='--output-check')
 
-        loader.add_loader_options(parser)
+        loader.add_loader_options(parser, 'run')
         parser_common_args.add_tag_filter_args(parser)
 
     def run(self, config):
@@ -307,9 +313,4 @@ class Run(CLICmd):
                 # Run JobPost plugins
                 pre_post_dispatcher.map_method('post', job_instance)
 
-            result_dispatcher = ResultDispatcher()
-            if result_dispatcher.extensions:
-                result_dispatcher.map_method('render',
-                                             job_instance.result,
-                                             job_instance)
         return job_run
