@@ -48,8 +48,8 @@ GDB_PATH = None
 #: Path to the gdbserver binary
 GDBSERVER_PATH = None
 
-GDB_PROMPT = '(gdb)'
-GDB_EXIT = '^exit'
+GDB_PROMPT = b'(gdb)'
+GDB_EXIT = b'^exit'
 GDB_BREAK_CONDITIONS = [GDB_PROMPT, GDB_EXIT]
 
 #: How the remote protocol signals a transmission success (in ACK mode)
@@ -111,7 +111,7 @@ def parse_mi(line):
     """
     if not line.endswith('\n'):
         line = "%s\n" % line
-    return gdbmi_parser.process(line)
+    return gdbmi_parser.session().process(line)
 
 
 def encode_mi_cli(command):
@@ -350,7 +350,8 @@ class GDB:
         """
         if not command.endswith('\n'):
             command = "%s\n" % command
-        self.process.stdin.write(command)
+        self.process.stdin.write(command.encode())
+        self.process.stdin.flush()
 
     def cmd(self, command):
         """
@@ -371,7 +372,7 @@ class GDB:
             # If the line can not be properly parsed, it is *most likely*
             # generated by the application being run inside the debugger
             try:
-                parsed_response = parse_mi(line)
+                parsed_response = parse_mi(line.decode())
             except Exception:  # pylint: disable=W0703
                 cmd.application_output.append(line)
                 continue
@@ -795,7 +796,7 @@ class GDBRemote:
 
         https://sourceware.org/gdb/current/onlinedocs/gdb/Packets.html#extended-mode
         """
-        self.cmd("!", "OK")
+        self.cmd(b"!", b"OK")
         self.extended_mode = True
 
     def start_no_ack_mode(self):
@@ -805,7 +806,7 @@ class GDBRemote:
 
         https://sourceware.org/gdb/current/onlinedocs/gdb/General-Query-Packets.html#QStartNoAckMode
         """
-        self.cmd("QStartNoAckMode", "OK")
+        self.cmd(b"QStartNoAckMode", b"OK")
         self.no_ack_mode = True
 
     def connect(self):
