@@ -4,7 +4,7 @@ import sys
 from avocado.core.job import Job
 
 config = {
-    'test_runner': 'nrunner',
+    'run.test_runner': 'nrunner',
     'run.references': [
         'selftests/unit/test_resolver.py',
         'selftests/functional/test_argument_parsing.py',
